@@ -67,11 +67,11 @@ resolver = "2" # avoid dependency conflicts on some platforms
 edition = "2018"
 
 [dependencies]
-sixtyfps = "0.1.1"
+sixtyfps = "0.1.2"
 ...
 
 [build-dependencies]
-sixtyfps-build = "0.1.1"
+sixtyfps-build = "0.1.2"
 ```
 
 In the `build.rs` file:
@@ -109,6 +109,7 @@ the following convenience functions are available through the [`ComponentHandle`
   - [`fn hide(&self)`](docs::generated_code::SampleComponent::hide): to hide the window of the component.
   - [`fn run(&self)`](docs::generated_code::SampleComponent::run): a convenience function that first calls `show()`,
     followed by spinning the event loop, and `hide()` when returning from the event loop.
+  - [`fn global<T: Global<Self>>(&self) -> T`](docs::generated_code::SampleComponent::global): an accessor to the global singletons,
 
 For each top-level property
   - A setter [`fn set_<property_name>(&self, value: <PropertyType>)`](docs::generated_code::SampleComponent::set_counter)
@@ -118,6 +119,8 @@ For each top-level callback
   - [`fn invoke_<callback_name>(&self)`](docs::generated_code::SampleComponent::invoke_hello): to invoke the callback
   - [`fn on_<callback_name>(&self, callback: impl Fn(<CallbackArgs>) + 'static)`](docs::generated_code::SampleComponent::on_hello): to set the callback handler.
 
+Note that all dashes (`-`) are replaced by underscores (`_`) in names of types or functions.
+
 After instantiating the component you can call just [`ComponentHandle::run()`] on it, in order to show it and spin the event loop to
 render and react to input events. If you want to show multiple components simultaneously, then you can also call just
 [`ComponentHandle::show()`] first. When you're ready to enter the event loop, just call [`run_event_loop()`].
@@ -177,6 +180,24 @@ struct MyStruct {
 }
 ```
 
+## Exported Global singletons
+
+When you export a [global singleton](docs::langref#global-singletons) from the main file,
+it is also generated with the exported name. Like the main component, the generated struct have
+inherent method to access the properties and callback:
+
+For each property
+  - A setter: `fn set_<property_name>(&self, value: <PropertyType>)`
+  - A getter: `fn get_<property_name>(&self) -> <PropertyType>`
+
+For each callback
+  - `fn invoke_<callback_name>(&self, <CallbackArgs>) -> <ReturnValue>` to invoke the callback
+  - `fn on_<callback_name>(&self, callback: impl Fn(<CallbackArgs>) + 'static)` to set the callback handler.
+
+The global can be accessed with the [`ComponentHandle::global()`] function, or with [`Global::get()`]
+
+See the [documentation of the `Global` trait](Global) for an example.
+
 */
 
 #![warn(missing_docs)]
@@ -421,6 +442,43 @@ pub fn invoke_from_event_loop(func: impl FnOnce() + Send + 'static) {
     sixtyfps_rendering_backend_default::backend().post_event(Box::new(func))
 }
 
+/// This trait is used to obtain references to global singletons exported in `.60`
+/// markup. Alternatively, you can use [`ComponentHandle::global`] to obtain access.
+///
+/// This trait is implemented by the compiler for each global singleton that's exported.
+///
+/// # Example
+/// The following example of `.60` markup defines a global singleton called `Palette`, exports
+/// it and modifies it from Rust code:
+/// ```rust
+/// sixtyfps::sixtyfps!{
+/// export global Palette := {
+///     property<color> foreground-color;
+///     property<color> background-color;
+/// }
+///
+/// export App := Window {
+///    background: Palette.background-color;
+///    Text {
+///       text: "Hello";
+///       color: Palette.foreground-color;
+///    }
+///    // ...
+/// }
+/// }
+/// let app = App::new();
+/// app.global::<Palette>().set_background_color(sixtyfps::Color::from_rgb_u8(0, 0, 0));
+///
+/// // alternate way to access the global singleton:
+/// Palette::get(&app).set_foreground_color(sixtyfps::Color::from_rgb_u8(255, 255, 255));
+/// ```
+///
+/// See also the [language reference for global singletons](docs/langref/index.html#global-singletons) for more information.
+pub trait Global<'a, Component> {
+    /// Returns a reference that's tied to the life time of the provided component.
+    fn get(component: &'a Component) -> Self;
+}
+
 /// This trait describes the common public API of a strongly referenced SixtyFPS component.
 /// It allows creating strongly-referenced clones, a conversion into/ a weak pointer as well
 /// as other convenience functions.
@@ -460,6 +518,12 @@ pub trait ComponentHandle {
     /// This is a convenience function that first calls [`Self::show`], followed by [`crate::run_event_loop()`]
     /// and [`Self::hide`].
     fn run(&self);
+
+    /// This function provides access to instances of global singletons exported in `.60`.
+    /// See [`Global`] for an example how to export and access globals from `.60` markup.
+    fn global<'a, T: Global<'a, Self>>(&'a self) -> T
+    where
+        Self: Sized;
 }
 
 mod weak_handle {
@@ -652,7 +716,7 @@ macro_rules! include_modules {
 /// Helper type that helps checking that the generated code is generated for the right version
 #[doc(hidden)]
 #[allow(non_camel_case_types)]
-pub struct VersionCheck_0_1_1;
+pub struct VersionCheck_0_1_2;
 
 #[cfg(doctest)]
 mod compile_fail_tests;
